@@ -19,14 +19,16 @@ If the WARC contains multiple entries for the same URL, only the first entry is
 """
 
 import os
+import sys
 import pathlib
 import logging
+import tempfile
 import mimetypes
 import datetime
 import re
 import time
 from argparse import ArgumentParser
-from urllib.parse import urlsplit, urljoin
+from urllib.parse import urlsplit, urljoin, urlunsplit
 
 import pkg_resources
 import requests
@@ -248,15 +250,23 @@ class WARC2Zim:
 
         self.full_filename = os.path.join(self.output, self.zim_file)
 
-        self.inputs = args.inputs
+        # ensure output file is writable
+        with tempfile.NamedTemporaryFile(dir=self.output, delete=True) as fh:
+            logger.debug(f"Confirming output is writable using {fh.name}")
+
+        self.inputs = [pathlib.Path(path) for path in args.inputs]
         self.replay_viewer_source = args.replay_viewer_source
 
         self.main_url = args.url
-        self.include_all = args.include_all
+        # ensure trailing slash is added if missing
+        parts = urlsplit(self.main_url)
+        if parts.path == "":
+            parts = list(parts)
+            # set path
+            parts[2] = "/"
+            self.main_url = urlunsplit(parts)
+
         self.include_domains = args.include_domains
-        if self.main_url:
-            if not self.include_all and not self.include_domains:
-                self.include_domains = [urlsplit(self.main_url).netloc]
 
         self.favicon_url = args.favicon
         self.language = args.lang
@@ -305,6 +315,12 @@ class WARC2Zim:
         return env
 
     def run(self):
+        if not self.inputs:
+            logger.info(
+                "Arguments valid, no inputs to process. Exiting with error code 100"
+            )
+            return 100
+
         self.find_main_page_metadata()
 
         # make sure Language metadata is ISO-639-3 and setup translations
@@ -347,9 +363,20 @@ class WARC2Zim:
                 if article:
                     zimcreator.add_zim_article(article)
 
-    def iter_warc_records(self):
-        for warcfile in self.inputs:
-            with open(warcfile, "rb") as warc_fh:
+    def iter_warc_records(self, dir_iter=None):
+        curr_iter = dir_iter or iter(self.inputs)
+
+        for filename in curr_iter:
+            if filename.is_dir():
+                yield from self.iter_warc_records(filename.iterdir())
+                continue
+
+            # for directory iterator, only accept .warc, .warc.gz files
+            # (accept all files directly specified in self.inputs)
+            if dir_iter and not filename.name.endswith((".warc", ".warc.gz")):
+                continue
+
+            with open(filename, "rb") as warc_fh:
                 for record in ArchiveIterator(warc_fh):
                     if record.rec_type not in ("resource", "response", "revisit"):
                         continue
@@ -377,8 +404,6 @@ class WARC2Zim:
                 )
             ):
                 self.main_url = url
-                if not self.include_all and not self.include_domains:
-                    self.include_domains = [urlsplit(self.main_url).netloc]
 
             if self.main_url != url:
                 continue
@@ -489,8 +514,8 @@ class WARC2Zim:
             logger.debug("Skipping duplicate {0}, already added to ZIM".format(url))
             return
 
-        # if not include_all, only include urls from main_url domain or subdomain
-        if not self.include_all:
+        # if include_domains is set, only include urls from those domains
+        if self.include_domains:
             parts = urlsplit(url)
             if not any(
                 parts.netloc.endswith(domain) for domain in self.include_domains
@@ -549,7 +574,7 @@ def warc2zim(args=None):
 
     parser.add_argument(
         "inputs",
-        nargs="+",
+        nargs="*",
         help="""Paths of directories and/or files to be included in
                                 the WARC file.""",
     )
@@ -566,18 +591,11 @@ def warc2zim(args=None):
         help="""The main url that should be loaded in the viewer on init""",
     )
 
-    parser.add_argument(
-        "-a",
-        "--include-all",
-        action="store_true",
-        help="If set, include all URLs in ZIM, not just those specified in --include-domains",
-    )
-
     parser.add_argument(
         "-i",
         "--include-domains",
         action="append",
-        help="List of domains that should be included. Not used if --include-all is set. Defaults to domain of the main url",
+        help="Limit ZIM file to URLs from only certain domains. If not set, all URLs in the input WARCs are included.",
     )
 
     parser.add_argument(
@@ -629,4 +647,4 @@ def get_version():
 
 # ============================================================================
 if __name__ == "__main__":  # pragma: no cover
-    warc2zim()
+    sys.exit(warc2zim())
